@@ -1,4 +1,4 @@
-from verify import get_errors_fails, mark_incomplete, mark_complete
+from .verify import get_errors_fails, mark_incomplete, mark_complete
 
 errors = get_errors_fails('milestone_1.txt')
 
@@ -16,11 +16,16 @@ elif 'test_presence' in errors:
     # mark_incomplete(task2_id, message='There is no hangman_solution.py file inside the hangman folder')
     mark_incomplete(task2_id)
     mark_incomplete(task3_id)
+    print(errors['test_presence'])
 # Check if they are identical
 elif 'test_diff' in errors:
     mark_incomplete(task3_id)
+    print(errors['test_diff'])
+
     # mark_incomplete(task3_id, message='No changes were made to hangman_solution.py')
 elif 'test_presence_ask_letter' in errors:
     # mark_incomplete(task3_id, message='The play_game() function is not using the ask_letter method')
     mark_incomplete(task3_id)
+    print(errors['test_presence_ask_letter'])
+
 
