@@ -1,4 +1,4 @@
-from verify import get_errors_fails, mark_incomplete, mark_complete
+from .verify import get_errors_fails, mark_incomplete, mark_complete
 
 errors = get_errors_fails('milestone_3.txt')
 task1_id = 'fbabd296-6512-413d-b26b-2991ed2f6941' # Check if the letter is in the word
@@ -14,6 +14,7 @@ if 'test_check_ask_letter_right' in errors and 'test_check_ask_letter_wrong_gues
     mark_incomplete(task1_id)
     mark_incomplete(task2_id)
     mark_incomplete(task3_id)
+    print('The Check letter method is not correctly set')
 elif 'test_check_ask_letter_right' in errors:
     mark_complete(task1_id)
     mark_incomplete(task2_id)
